StoryModel<A> class

Constructors

StoryModel({A? data, String audioUrl = '', String imageUrl = '', String thumbnailUrl = '', StoryImageType storyType = StoryImageType.Image})

Properties

audioUrl String
final
data → A?
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String
final
isInitialize ValueNotifier<bool>
final
isInitThumbnail ValueNotifier<bool>
final
isThumbnailUrl bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyType StoryImageType
final
thumbnailUrl String
getter/setter pair
videoPlayer ↔ VideoPlayerController?
getter/setter pair

Methods

dispose() → void
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited